pub fn fmt_diag_string(e: &dyn ErrorDiagnostic) -> StringExpand description
Formats a full diagnostic view of an error for logging and tracing.
pub fn fmt_diag_string(e: &dyn ErrorDiagnostic) -> StringFormats a full diagnostic view of an error for logging and tracing.