fmt_diag_typ

Function fmt_diag_typ 

pub fn fmt_diag_typ<T>(
    f: &mut dyn Write,
    typ: Option<ResultType>,
    e: &T,
) -> Result
where T: ErrorDiagnostic,
Formats a full diagnostic view of an error for logging and tracing.

For ServiceError types, this includes debug representations of all nested errors, and a backtrace when available.