pub struct Backtrace(/* private fields */);Expand description
Representation of a backtrace.
This structure can be used to capture a backtrace at various points in a program and later used to inspect what the backtrace was at that time.
Implementations