pub fn module_path_prefix(prefix: &'static str, file_path: &str) -> ByteStringExpand description
Generates a module path with a prefix from the given file path.
pub fn module_path_prefix(prefix: &'static str, file_path: &str) -> ByteStringGenerates a module path with a prefix from the given file path.