pub async fn with_service<F, T, E>(svc: &'static str, fut: F) -> F::Outputwhere F: Future<Output = Result<T, Error<E>>>, E: ErrorDiagnostic + Clone,
Executes a future and ensures an error service is set.
If the error does not already have a service, the provided service is assigned.