pub fn fmt_diag<'a, T>(f: &mut dyn Write, container: &'a T) -> ResultExpand description
Formats a full diagnostic view of an error for logging and tracing.
For ServiceError types, this includes debug representations of all nested errors,
and a backtrace when available.