pub fn fmt_diag_string<K: ResultKind>(
e: &dyn ErrorDiagnostic<Kind = K>,
) -> StringExpand description
Formats a full diagnostic view of an error for logging and tracing.
pub fn fmt_diag_string<K: ResultKind>(
e: &dyn ErrorDiagnostic<Kind = K>,
) -> StringFormats a full diagnostic view of an error for logging and tracing.