pub fn fmt_diag_typ<T>(
f: &mut dyn Write,
typ: Option<ResultType>,
e: &T,
) -> Resultwhere
T: ErrorDiagnostic,Expand description
Formats a full diagnostic view of an error for logging and tracing.
For ServiceError types, this includes debug representations of all nested errors,
and a backtrace when available.