Module utils

Module utils 

Structs

Success

Functions

module_path
Generates a module path from the given file path.
module_path_fs
Generates a module path from a file path.
module_path_prefix
Generates a module path with a prefix from the given file path.
with_service
Executes a future and ensures an error service is set.