pub fn module_path_prefix(prefix: &'static str, file_path: &str) -> ByteStringExpand description
Generate module path with prefix for the file path
pub fn module_path_prefix(prefix: &'static str, file_path: &str) -> ByteStringGenerate module path with prefix for the file path